@@ -3,12 +3,13 @@ package NetHack::Item::Food;
 use Moose;
 extends 'NetHack::Item';
 
+use constant subtypes => "corpse";
 use constant type => "food";
 
 has is_partly_eaten => (
+    traits  => [qw/IncorporatesUndef/],
     is      => 'rw',
     isa     => 'Bool',
-    default => 0,
 );
 
 has is_laid_by_you => (
@@ -25,6 +26,13 @@ after incorporate_stats => sub {
     $self->is_laid_by_you($stats->{laid});
 };
 
+after incorporate_stats_from => sub {
+    my $self  = shift;
+    my $other = shift;
+
+    $self->incorporate_stat($other => 'is_partly_eaten');
+};
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
