@@ -11,11 +11,17 @@ has is_chained_to_you => (
     default => 0,
 );
 
+has statue => (
+    is  => 'rw',
+    isa => 'Str',
+);
+
 after incorporate_stats => sub {
     my $self  = shift;
     my $stats = shift;
 
     $self->is_chained_to_you($stats->{chained});
+    $self->statue($stats->{statue}) if exists $stats->{statue};
 };
 
 __PACKAGE__->meta->make_immutable;
