@@ -7,6 +7,7 @@ with 'NetHack::Item::Role::Lightable';
 use constant type => "potion";
 
 has is_diluted => (
+    traits  => [qw/IncorporatesUndef/],
     is      => 'rw',
     isa     => 'Bool',
     default => 0,
@@ -19,6 +20,13 @@ after incorporate_stats => sub {
     $self->is_diluted($stats->{diluted});
 };
 
+after incorporate_stats_from => sub {
+    my $self  = shift;
+    my $other = shift;
+
+    $self->incorporate_stat($other => 'is_diluted');
+};
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 
