@@ -4,15 +4,14 @@ use strict;
 use warnings;
 use base 'NetHack::Item::Spoiler';
 
-use Memoize;
-memoize 'list';
+use constant type => 'armor';
 
 my @cloaks  = ('tattered cape', 'opera cloak', 'ornamental cope', 'piece of cloth');
 my @helmets = map { "$_ helmet" } qw/plumed etched crested visored/;
 my @gloves  = map { "$_ gloves" } qw/old padded riding fencing/;
 my @boots   = map { "$_ boots"  } qw/combat jungle hiking mud buckled riding snow/;
 
-sub list {
+sub _list {
     my $armor = {
         'Mitre of Holiness' => {
             artifact   => 1,
@@ -20,7 +19,9 @@ sub list {
             value      => 2000,
             weight     => 50,
             ac         => 1,
+            fullname   => 'The Mitre of Holiness',
             material   => 'iron',
+            subtype    => 'helmet',
         },
 
         'Hawaiian shirt' => {
@@ -28,12 +29,14 @@ sub list {
             weight     => 5,
             ac         => 0,
             material   => 'cloth',
+            subtype    => 'shirt',
         },
         'T-shirt' => {
             value      => 2,
             weight     => 5,
             ac         => 0,
             material   => 'cloth',
+            subtype    => 'shirt',
         },
 
         'leather jacket' => {
@@ -41,12 +44,14 @@ sub list {
             weight     => 30,
             ac         => 1,
             material   => 'leather',
+            subtype    => 'bodyarmor',
         },
         'leather armor' => {
             value      => 5,
             weight     => 150,
             ac         => 2,
             material   => 'leather',
+            subtype    => 'bodyarmor',
         },
         'orcish ring mail' => {
             value      => 80,
@@ -55,6 +60,7 @@ sub list {
             material   => 'iron',
             mc         => 1,
             appearance => 'crude ring mail',
+            subtype    => 'bodyarmor',
         },
         'studded leather armor' => {
             value      => 15,
@@ -62,18 +68,21 @@ sub list {
             ac         => 3,
             material   => 'leather',
             mc         => 1,
+            subtype    => 'bodyarmor',
         },
         'ring mail' => {
             value      => 100,
             weight     => 250,
             ac         => 3,
             material   => 'iron',
+            subtype    => 'bodyarmor',
         },
         'scale mail' => {
             value      => 45,
             weight     => 250,
             ac         => 4,
             material   => 'iron',
+            subtype    => 'bodyarmor',
         },
         'orcish chain mail' => {
             value      => 75,
@@ -82,6 +91,7 @@ sub list {
             material   => 'iron',
             mc         => 1,
             appearance => 'crude chain mail',
+            subtype    => 'bodyarmor',
         },
         'chain mail' => {
             value      => 75,
@@ -89,6 +99,7 @@ sub list {
             ac         => 5,
             material   => 'iron',
             mc         => 1,
+            subtype    => 'bodyarmor',
         },
         'elven mithril-coat' => {
             value      => 240,
@@ -96,6 +107,7 @@ sub list {
             ac         => 5,
             material   => 'mithril',
             mc         => 3,
+            subtype    => 'bodyarmor',
         },
         'splint mail' => {
             value      => 80,
@@ -103,12 +115,14 @@ sub list {
             ac         => 6,
             material   => 'iron',
             mc         => 1,
+            subtype    => 'bodyarmor',
         },
         'banded mail' => {
             value      => 90,
             weight     => 350,
             ac         => 6,
             material   => 'iron',
+            subtype    => 'bodyarmor',
         },
         'dwarvish mithril-coat' => {
             value      => 240,
@@ -116,12 +130,14 @@ sub list {
             ac         => 6,
             material   => 'mithril',
             mc         => 3,
+            subtype    => 'bodyarmor',
         },
         'bronze plate mail' => {
             value      => 400,
             weight     => 450,
             ac         => 6,
             material   => 'copper',
+            subtype    => 'bodyarmor',
         },
         'plate mail' => {
             value      => 600,
@@ -129,6 +145,7 @@ sub list {
             ac         => 7,
             material   => 'iron',
             mc         => 2,
+            subtype    => 'bodyarmor',
         },
         'crystal plate mail' => {
             value      => 820,
@@ -136,114 +153,133 @@ sub list {
             ac         => 7,
             material   => 'glass',
             mc         => 2,
+            subtype    => 'bodyarmor',
         },
         'red dragon scales' => {
             value      => 500,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'white dragon scales' => {
             value      => 500,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'orange dragon scales' => {
             value      => 500,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'blue dragon scales' => {
             value      => 500,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'green dragon scales' => {
             value      => 500,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'yellow dragon scales' => {
             value      => 500,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'black dragon scales' => {
             value      => 700,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'silver dragon scales' => {
             value      => 700,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'gray dragon scales' => {
             value      => 700,
             weight     => 40,
             ac         => 3,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'red dragon scale mail' => {
             value      => 900,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'white dragon scale mail' => {
             value      => 900,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'orange dragon scale mail' => {
             value      => 900,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'blue dragon scale mail' => {
             value      => 900,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'green dragon scale mail' => {
             value      => 900,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'yellow dragon scale mail' => {
             value      => 900,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'black dragon scale mail' => {
             value      => 1200,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'silver dragon scale mail' => {
             value      => 1200,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
         'gray dragon scale mail' => {
             value      => 1200,
             weight     => 40,
             ac         => 9,
             material   => 'dragon hide',
+            subtype    => 'bodyarmor',
         },
 
         'mummy wrapping' => {
@@ -252,6 +288,7 @@ sub list {
             ac         => 0,
             material   => 'cloth',
             mc         => 1,
+            subtype    => 'cloak',
         },
         'orcish cloak' => {
             value      => 40,
@@ -260,6 +297,7 @@ sub list {
             material   => 'cloth',
             mc         => 2,
             appearance => 'coarse mantelet',
+            subtype    => 'cloak',
         },
         'dwarvish cloak' => {
             value      => 50,
@@ -268,6 +306,7 @@ sub list {
             material   => 'cloth',
             mc         => 2,
             appearance => 'hooded cloak',
+            subtype    => 'cloak',
         },
         'leather cloak' => {
             value      => 40,
@@ -275,6 +314,7 @@ sub list {
             ac         => 1,
             material   => 'leather',
             mc         => 1,
+            subtype    => 'cloak',
         },
         'oilskin cloak' => {
             value      => 50,
@@ -283,6 +323,7 @@ sub list {
             material   => 'cloth',
             mc         => 3,
             appearance => 'slippery cloak',
+            subtype    => 'cloak',
         },
         'alchemy smock' => {
             value      => 50,
@@ -291,6 +332,7 @@ sub list {
             material   => 'cloth',
             mc         => 1,
             appearance => 'apron',
+            subtype    => 'cloak',
         },
         'elven cloak' => {
             value      => 60,
@@ -299,6 +341,7 @@ sub list {
             material   => 'cloth',
             mc         => 3,
             appearance => 'faded pall',
+            subtype    => 'cloak',
         },
         'robe' => {
             value      => 50,
@@ -306,6 +349,7 @@ sub list {
             ac         => 2,
             material   => 'cloth',
             mc         => 3,
+            subtype    => 'cloak',
         },
         'cloak of displacement' => {
             value       => 50,
@@ -314,6 +358,7 @@ sub list {
             material    => 'cloth',
             mc          => 2,
             appearances => \@cloaks,
+            subtype    => 'cloak',
         },
         'cloak of invisibility' => {
             value       => 60,
@@ -322,6 +367,7 @@ sub list {
             material    => 'cloth',
             mc          => 2,
             appearances => \@cloaks,
+            subtype    => 'cloak',
         },
         'cloak of magic resistance' => {
             value       => 60,
@@ -330,6 +376,7 @@ sub list {
             material    => 'cloth',
             mc          => 3,
             appearances => \@cloaks,
+            subtype    => 'cloak',
         },
         'cloak of protection' => {
             value       => 50,
@@ -338,6 +385,7 @@ sub list {
             material    => 'cloth',
             mc          => 3,
             appearances => \@cloaks,
+            subtype    => 'cloak',
         },
 
         'fedora' => {
@@ -345,6 +393,7 @@ sub list {
             weight     => 3,
             ac         => 0,
             material   => 'cloth',
+            subtype    => 'helmet',
         },
         'dunce cap' => {
             value      => 1,
@@ -352,6 +401,7 @@ sub list {
             ac         => 0,
             material   => 'cloth',
             appearance => 'conical hat',
+            subtype    => 'helmet',
         },
         'cornuthaum' => {
             value      => 80,
@@ -360,12 +410,14 @@ sub list {
             material   => 'cloth',
             mc         => 2,
             appearance => 'conical hat',
+            subtype    => 'helmet',
         },
         'dented pot' => {
             value      => 8,
             weight     => 10,
             ac         => 1,
             material   => 'iron',
+            subtype    => 'helmet',
         },
         'elven leather helm' => {
             value      => 8,
@@ -373,6 +425,7 @@ sub list {
             ac         => 1,
             material   => 'leather',
             appearance => 'leather hat',
+            subtype    => 'helmet',
         },
         'orcish helm' => {
             value      => 10,
@@ -380,6 +433,7 @@ sub list {
             ac         => 1,
             material   => 'iron',
             appearance => 'iron skull cap',
+            subtype    => 'helmet',
         },
         'dwarvish iron helm' => {
             value      => 20,
@@ -387,6 +441,7 @@ sub list {
             ac         => 2,
             material   => 'iron',
             appearance => 'hard hat',
+            subtype    => 'helmet',
         },
         'helmet' => {
             value       => 10,
@@ -394,6 +449,7 @@ sub list {
             ac          => 1,
             material    => 'iron',
             appearances => \@helmets,
+            subtype    => 'helmet',
         },
         'helm of brilliance' => {
             value       => 50,
@@ -401,6 +457,7 @@ sub list {
             ac          => 1,
             material    => 'iron',
             appearances => \@helmets,
+            subtype    => 'helmet',
         },
         'helm of opposite alignment' => {
             value       => 50,
@@ -408,6 +465,7 @@ sub list {
             ac          => 1,
             material    => 'iron',
             appearances => \@helmets,
+            subtype    => 'helmet',
         },
         'helm of telepathy' => {
             value       => 50,
@@ -415,6 +473,7 @@ sub list {
             ac          => 1,
             material    => 'iron',
             appearances => \@helmets,
+            subtype    => 'helmet',
         },
 
         'leather gloves' => {
@@ -423,6 +482,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@gloves,
+            subtype    => 'gloves',
         },
         'gauntlets of dexterity' => {
             value       => 50,
@@ -430,6 +490,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@gloves,
+            subtype    => 'gloves',
         },
         'gauntlets of fumbling' => {
             value       => 50,
@@ -437,6 +498,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@gloves,
+            subtype    => 'gloves',
         },
         'gauntlets of power' => {
             value       => 50,
@@ -444,6 +506,7 @@ sub list {
             ac          => 1,
             material    => 'iron',
             appearances => \@gloves,
+            subtype    => 'gloves',
         },
 
         'small shield' => {
@@ -451,6 +514,7 @@ sub list {
             weight     => 30,
             ac         => 1,
             material   => 'wood',
+            subtype    => 'shield',
         },
         'orcish shield' => {
             value      => 7,
@@ -458,6 +522,7 @@ sub list {
             ac         => 1,
             material   => 'iron',
             appearance => 'red-eyed shield',
+            subtype    => 'shield',
         },
         'Uruk-hai shield' => {
             value      => 7,
@@ -465,6 +530,7 @@ sub list {
             ac         => 1,
             material   => 'iron',
             appearance => 'white-handed shield',
+            subtype    => 'shield',
         },
         'elven shield' => {
             value      => 7,
@@ -472,6 +538,7 @@ sub list {
             ac         => 2,
             material   => 'wood',
             appearance => 'blue and green shield',
+            subtype    => 'shield',
         },
         'dwarvish roundshield' => {
             value      => 10,
@@ -479,12 +546,14 @@ sub list {
             ac         => 2,
             material   => 'iron',
             appearance => 'large round shield',
+            subtype    => 'shield',
         },
         'large shield' => {
             value      => 10,
             weight     => 100,
             ac         => 2,
             material   => 'iron',
+            subtype    => 'shield',
         },
         'shield of reflection' => {
             value      => 50,
@@ -492,6 +561,7 @@ sub list {
             ac         => 2,
             material   => 'silver',
             appearance => 'polished silver shield',
+            subtype    => 'shield',
         },
 
         'low boots' => {
@@ -500,6 +570,7 @@ sub list {
             ac         => 1,
             material   => 'leather',
             appearance => 'walking shoes',
+            subtype    => 'boots',
         },
         'high boots' => {
             value      => 12,
@@ -507,6 +578,7 @@ sub list {
             ac         => 2,
             material   => 'leather',
             appearance => 'jackboots',
+            subtype    => 'boots',
         },
         'iron shoes' => {
             value      => 16,
@@ -514,6 +586,7 @@ sub list {
             ac         => 2,
             material   => 'iron',
             appearance => 'hard shoes',
+            subtype    => 'boots',
         },
         'elven boots' => {
             value       => 8,
@@ -521,6 +594,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@boots,
+            subtype    => 'boots',
         },
         'kicking boots' => {
             value       => 8,
@@ -528,6 +602,7 @@ sub list {
             ac          => 1,
             material    => 'iron',
             appearances => \@boots,
+            subtype    => 'boots',
         },
         'fumble boots' => {
             value       => 30,
@@ -535,6 +610,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@boots,
+            subtype    => 'boots',
         },
         'levitation boots' => {
             value       => 30,
@@ -542,6 +618,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@boots,
+            subtype    => 'boots',
         },
         'jumping boots' => {
             value       => 50,
@@ -549,6 +626,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@boots,
+            subtype    => 'boots',
         },
         'speed boots' => {
             value       => 50,
@@ -556,6 +634,7 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@boots,
+            subtype    => 'boots',
         },
         'water walking boots' => {
             value       => 50,
@@ -563,18 +642,10 @@ sub list {
             ac          => 1,
             material    => 'leather',
             appearances => \@boots,
+            subtype    => 'boots',
         },
     };
 
-    # tag each armor with its name and appearance
-    for my $name (keys %$armor) {
-        my $stats = $armor->{$name};
-        $stats->{name}       = $name;
-        $stats->{type}       = 'armor';
-        $stats->{appearance} = $name
-            unless $stats->{appearance} || $stats->{appearances};
-    }
-
     return $armor;
 }
 
