@@ -4,10 +4,9 @@ use strict;
 use warnings;
 use base 'NetHack::Item::Spoiler';
 
-use Memoize;
-memoize 'list';
+use constant type => 'food';
 
-sub list {
+sub _list {
     my $food = {
         'meatball' => {
             price => 5, weight => 1, nutrition => 5, time => 1,
@@ -2087,15 +2086,6 @@ sub list {
         }
     }
 
-    # tag each food with its name, weight, appearances, etc
-    for my $name (keys %$food) {
-        my $stats = $food->{$name};
-        $stats->{name}       = $name;
-        $stats->{type}       = 'food';
-        $stats->{appearance} = $stats->{name}
-            unless $stats->{appearance} || $stats->{appearances};
-    }
-
     return $food;
 }
 
