@@ -4,251 +4,279 @@ use strict;
 use warnings;
 use base 'NetHack::Item::Spoiler';
 
-use Memoize;
-memoize 'list';
+use constant type => 'weapon';
 
-sub list {
+sub _list {
     my $weapons = {
             'Cleaver' => {
                 artifact => 1,
+                base     => 'battle-axe',
                 sdam     => 'd8+d6+d4',
                 ldam     => '2d6+2d4',
                 tohit    => 'd3',
                 hands    => 2,
                 weight   => 120,
                 price    => 1500,
-                material     => 'iron',
+                material => 'iron',
             },
             'Demonbane' => {
                 artifact => 1,
+                base     => 'long sword',
                 sdam     => 'd8',
                 ldam     => 'd12',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 2500,
-                material     => 'iron',
+                material => 'iron',
             },
             'Dragonbane' => {
                 artifact => 1,
+                base     => 'broadsword',
                 sdam     => '2d4',
                 ldam     => 'd6+1',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 500,
-                material     => 'iron',
+                material => 'iron',
             },
             'Excalibur' => {
                 artifact => 1,
+                base     => 'long sword',
                 sdam     => 'd8+d10',
                 ldam     => 'd12+d10',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 4000,
-                material     => 'iron',
+                material => 'iron',
             },
             'Fire Brand' => {
                 artifact => 1,
+                base     => 'long sword',
                 sdam     => 'd8',
                 ldam     => 'd12',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 3000,
-                material     => 'iron',
+                material => 'iron',
             },
             'Frost Brand' => {
                 artifact => 1,
+                base     => 'long sword',
                 sdam     => 'd8',
                 ldam     => 'd12',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 3000,
-                material     => 'iron',
+                material => 'iron',
             },
             'Giantslayer' => {
                 artifact => 1,
+                base     => 'long sword',
                 sdam     => 'd8',
                 ldam     => 'd12',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 200,
-                material     => 'iron',
+                material => 'iron',
             },
             'Grayswandir' => {
                 artifact => 1,
+                base     => 'silver saber',
                 sdam     => 'd8',
                 ldam     => 'd8',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 8000,
-                material     => 'silver',
+                material => 'silver',
             },
             'Grimtooth' => {
                 artifact => 1,
+                base     => 'orcish dagger',
                 sdam     => 'd6+d3',
                 ldam     => 'd6+d3',
                 tohit    => 'd2+2',
                 hands    => 1,
                 weight   => 10,
                 price    => 300,
-                material     => 'iron',
+                material => 'iron',
             },
             'Longbow of Diana' => {
                 artifact => 1,
+                base     => 'bow',
                 sdam     => 'd2',
                 ldam     => 'd2',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 30,
                 price    => 4000,
-                material     => 'wood',
+                fullname => 'The Longbow of Diana',
+                material => 'wood',
             },
             'Magicbane' => {
                 artifact => 1,
+                base     => 'athame',
                 sdam     => '2d4',
                 ldam     => 'd4+d3',
                 tohit    => 'd5+2',
                 hands    => 1,
                 weight   => 10,
                 price    => 3500,
-                material     => 'iron',
+                material => 'iron',
             },
             'Mjollnir' => {
                 artifact => 1,
+                base     => 'war hammer',
                 sdam     => 'd4+1',
                 ldam     => 'd4',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 50,
                 price    => 4000,
-                material     => 'iron',
+                material => 'iron',
             },
             'Ogresmasher' => {
                 artifact => 1,
+                base     => 'war hammer',
                 sdam     => 'd4+1',
                 ldam     => 'd4',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 50,
                 price    => 200,
-                material     => 'iron',
+                material => 'iron',
             },
             'Orcrist' => {
                 artifact => 1,
+                base     => 'elven broadsword',
                 sdam     => 'd6+d4',
                 ldam     => 'd6+1',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 70,
                 price    => 2000,
-                material     => 'wood',
+                material => 'wood',
             },
             'Sceptre of Might' => {
                 artifact => 1,
+                base     => 'mace',
                 sdam     => 'd6+1',
                 ldam     => 'd6',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 30,
                 price    => 2500,
-                material     => 'iron',
+                fullname => 'The Sceptre of Might',
+                material => 'iron',
             },
             'Snickersnee' => {
                 artifact => 1,
+                base     => 'katana',
                 sdam     => 'd10+d8',
                 ldam     => 'd12+d8',
                 tohit    => '1',
                 hands    => 1,
                 weight   => 40,
                 price    => 1200,
-                material     => 'iron',
+                material => 'iron',
             },
             'Staff of Aesculapius' => {
                 artifact => 1,
+                base     => 'quarterstaff',
                 sdam     => 'd6',
                 ldam     => 'd6',
                 tohit    => '0',
                 hands    => 2,
                 weight   => 40,
                 price    => 5000,
-                material     => 'wood',
+                fullname => 'The Staff of Aesculapius',
+                material => 'wood',
             },
             'Sting' => {
                 artifact => 1,
+                base     => 'elven dagger',
                 sdam     => 'd5',
                 ldam     => 'd3',
                 tohit    => 'd5+2',
                 hands    => 1,
                 weight   => 10,
                 price    => 800,
-                material     => 'wood',
+                material => 'wood',
             },
             'Stormbringer' => {
                 artifact => 1,
+                base     => 'runesword',
                 sdam     => '2d4+d2',
                 ldam     => 'd6+d2+1',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 8000,
-                material     => 'iron',
+                material => 'iron',
             },
             'Sunsword' => {
                 artifact => 1,
+                base     => 'long sword',
                 sdam     => 'd8',
                 ldam     => 'd12',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 1500,
-                material     => 'iron',
+                material => 'iron',
             },
-            'The Tsurugi of Muramasa' => {
+            'Tsurugi of Muramasa' => {
                 artifact => 1,
+                base     => 'tsurugi',
                 sdam     => 'd16+d8',
                 ldam     => '2d8+2d6',
                 tohit    => '2',
                 hands    => 2,
                 weight   => 60,
                 price    => 4500,
-                material     => 'metal',
+                fullname => 'The Tsurugi of Muramasa',
+                material => 'metal',
             },
             'Trollsbane' => {
                 artifact => 1,
+                base     => 'morning star',
                 sdam     => '2d4',
                 ldam     => 'd6+1',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 120,
                 price    => 200,
-                material     => 'iron',
+                material => 'iron',
             },
             'Vorpal Blade' => {
                 artifact => 1,
+                base     => 'long sword',
                 sdam     => 'd8+1',
                 ldam     => 'd12+1',
                 tohit    => 'd5',
                 hands    => 1,
                 weight   => 40,
                 price    => 4000,
-                material     => 'iron',
+                material => 'iron',
             },
             'Werebane' => {
                 artifact => 1,
+                base     => 'silver saber',
                 sdam     => 'd8',
                 ldam     => 'd8',
                 tohit    => 'd2',
                 hands    => 1,
                 weight   => 40,
                 price    => 1500,
-                material     => 'silver',
+                material => 'silver',
             },
+
             'aklys' => {
                 sdam     => 'd6',
                 ldam     => 'd3',
@@ -256,7 +284,7 @@ sub list {
                 hands    => 1,
                 weight   => 15,
                 price    => 4,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'thonged club',
                 plural => 'aklyses',
             },
@@ -267,7 +295,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 2,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'arrows',
             },
             'athame' => {
@@ -277,7 +305,7 @@ sub list {
                 hands    => 1,
                 weight   => 10,
                 price    => 4,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'athames',
             },
             'axe' => {
@@ -287,7 +315,7 @@ sub list {
                 hands    => 1,
                 weight   => 60,
                 price    => 8,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'axes',
             },
             'bardiche' => {
@@ -297,7 +325,7 @@ sub list {
                 hands    => 2,
                 weight   => 120,
                 price    => 7,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'long poleaxe',
                 plural => 'bardiches',
             },
@@ -308,7 +336,7 @@ sub list {
                 hands    => 2,
                 weight   => 120,
                 price    => 40,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'double-headed axe',
                 plural => 'battle-axes',
             },
@@ -319,7 +347,7 @@ sub list {
                 hands    => 2,
                 weight   => 100,
                 price    => 8,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'beaked polearm',
                 plural => 'bec de corbins',
             },
@@ -330,7 +358,7 @@ sub list {
                 hands    => 2,
                 weight   => 120,
                 price    => 7,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'hooked polearm',
                 plural => 'bill-guisarmes',
             },
@@ -341,7 +369,7 @@ sub list {
                 hands    => 1,
                 weight   => 5,
                 price    => 20,
-                material     => 'wood',
+                material => 'wood',
                 plural => 'boomerangs',
             },
             'bow' => {
@@ -351,7 +379,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 60,
-                material     => 'wood',
+                material => 'wood',
                 plural => 'bows',
             },
             'broadsword' => {
@@ -361,7 +389,7 @@ sub list {
                 hands    => 1,
                 weight   => 70,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'broadswords',
             },
             'bullwhip' => {
@@ -371,7 +399,7 @@ sub list {
                 hands    => 1,
                 weight   => 20,
                 price    => 4,
-                material     => 'leather',
+                material => 'leather',
                 plural => 'bullwhips',
             },
             'club' => {
@@ -381,7 +409,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 3,
-                material     => 'wood',
+                material => 'wood',
                 plural => 'clubs',
             },
             'crossbow' => {
@@ -391,7 +419,7 @@ sub list {
                 hands    => 1,
                 weight   => 50,
                 price    => 40,
-                material     => 'wood',
+                material => 'wood',
                 plural => 'crossbows',
             },
             'crossbow bolt' => {
@@ -401,7 +429,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 2,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'crossbow bolts',
             },
             'crysknife' => {
@@ -411,7 +439,7 @@ sub list {
                 hands    => 1,
                 weight   => 20,
                 price    => 100,
-                material     => 'mineral',
+                material => 'mineral',
                 plural => 'crysknives',
             },
             'dagger' => {
@@ -421,7 +449,7 @@ sub list {
                 hands    => 1,
                 weight   => 10,
                 price    => 4,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'daggers',
             },
             'dart' => {
@@ -431,7 +459,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 2,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'darts',
             },
             'dwarvish mattock' => {
@@ -441,7 +469,7 @@ sub list {
                 hands    => 2,
                 weight   => 120,
                 price    => 50,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'broad pick',
                 plural => 'dwarvish mattocks',
             },
@@ -452,7 +480,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'broad short sword',
                 plural => 'dwarvish short swords',
             },
@@ -463,7 +491,7 @@ sub list {
                 hands    => 1,
                 weight   => 35,
                 price    => 3,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'stout spear',
                 plural => 'dwarvish spears',
             },
@@ -474,7 +502,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 2,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'runed arrow',
                 plural => 'elven arrows',
             },
@@ -485,7 +513,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 60,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'runed bow',
                 plural => 'elven bows',
             },
@@ -496,7 +524,7 @@ sub list {
                 hands    => 1,
                 weight   => 70,
                 price    => 10,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'runed broadsword',
                 plural => 'elven broadswords',
             },
@@ -507,7 +535,7 @@ sub list {
                 hands    => 1,
                 weight   => 10,
                 price    => 4,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'runed dagger',
                 plural => 'elven daggers',
             },
@@ -518,7 +546,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 10,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'runed short sword',
                 plural => 'elven short swords',
             },
@@ -529,7 +557,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 3,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'runed spear',
                 plural => 'elven spears',
             },
@@ -540,7 +568,7 @@ sub list {
                 hands    => 2,
                 weight   => 60,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'pole sickle',
                 plural => 'fauchards',
             },
@@ -551,7 +579,7 @@ sub list {
                 hands    => 1,
                 weight   => 15,
                 price    => 4,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'flails',
             },
             'flintstone' => {
@@ -561,7 +589,7 @@ sub list {
                 hands    => 1,
                 weight   => 10,
                 price    => 1,
-                material     => 'mineral',
+                material => 'mineral',
                 plural => 'flintstones',
             },
             'glaive' => {
@@ -571,7 +599,7 @@ sub list {
                 hands    => 2,
                 weight   => 75,
                 price    => 6,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'single-edged polearm',
                 plural => 'glaives',
             },
@@ -582,7 +610,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 50,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'iron hook',
                 plural => 'grappling hooks',
             },
@@ -593,7 +621,7 @@ sub list {
                 hands    => 2,
                 weight   => 80,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'pruning hook',
                 plural => 'guisarmes',
             },
@@ -604,7 +632,7 @@ sub list {
                 hands    => 2,
                 weight   => 150,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'angled poleaxe',
                 plural => 'halberds',
             },
@@ -615,7 +643,7 @@ sub list {
                 hands    => 1,
                 weight   => 20,
                 price    => 3,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'throwing spear',
                 plural => 'javelins',
             },
@@ -626,7 +654,7 @@ sub list {
                 hands    => 1,
                 weight   => 40,
                 price    => 80,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'samurai sword',
                 plural => 'katanas',
             },
@@ -637,7 +665,7 @@ sub list {
                 hands    => 1,
                 weight   => 5,
                 price    => 4,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'knives',
             },
             'lance' => {
@@ -647,7 +675,7 @@ sub list {
                 hands    => 1,
                 weight   => 180,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'lances',
             },
             'long sword' => {
@@ -657,7 +685,7 @@ sub list {
                 hands    => 1,
                 weight   => 40,
                 price    => 15,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'long swords',
             },
             'lucern hammer' => {
@@ -667,7 +695,7 @@ sub list {
                 hands    => 2,
                 weight   => 150,
                 price    => 7,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'pronged polearm',
                 plural => 'lucern hammers',
             },
@@ -678,7 +706,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'maces',
             },
             'morning star' => {
@@ -688,7 +716,7 @@ sub list {
                 hands    => 1,
                 weight   => 120,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'morning stars',
             },
             'orcish arrow' => {
@@ -698,7 +726,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 2,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'crude arrow',
                 plural => 'orcish arrows',
             },
@@ -709,7 +737,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 60,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'crude bow',
                 plural => 'orcish bows',
             },
@@ -720,7 +748,7 @@ sub list {
                 hands    => 1,
                 weight   => 10,
                 price    => 4,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'crude dagger',
                 plural => 'orcish daggers',
             },
@@ -731,7 +759,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'crude short sword',
                 plural => 'orcish short swords',
             },
@@ -742,7 +770,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 3,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'crude spear',
                 plural => 'orcish spears',
             },
@@ -753,7 +781,7 @@ sub list {
                 hands    => 2,
                 weight   => 80,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'vulgar polearm',
                 plural => 'partisans',
             },
@@ -764,7 +792,7 @@ sub list {
                 hands    => 1,
                 weight   => 100,
                 price    => 50,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'pick-axes',
             },
             'quarterstaff' => {
@@ -774,7 +802,7 @@ sub list {
                 hands    => 2,
                 weight   => 40,
                 price    => 5,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'staff',
                 plural => 'quarterstaves',
             },
@@ -785,7 +813,7 @@ sub list {
                 hands    => 2,
                 weight   => 50,
                 price    => 6,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'hilted polearm',
                 plural => 'ranseurs',
             },
@@ -796,7 +824,7 @@ sub list {
                 hands    => 1,
                 weight   => 20,
                 price    => 3,
-                material     => 'plastic',
+                material => 'plastic',
                 plural => 'rubber hoses',
             },
             'runesword' => {
@@ -806,7 +834,7 @@ sub list {
                 hands    => 1,
                 weight   => 40,
                 price    => 300,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'runed broadsword',
                 plural => 'runeswords',
             },
@@ -817,7 +845,7 @@ sub list {
                 hands    => 1,
                 weight   => 5,
                 price    => 6,
-                material     => 'metal',
+                material => 'metal',
                 plural => 'scalpels',
             },
             'scimitar' => {
@@ -827,7 +855,7 @@ sub list {
                 hands    => 1,
                 weight   => 40,
                 price    => 15,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'curved sword',
                 plural => 'scimitars',
             },
@@ -838,7 +866,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 10,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'short swords',
             },
             'shuriken' => {
@@ -848,7 +876,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'throwing star',
                 plural => 'shuriken',
             },
@@ -859,7 +887,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 5,
-                material     => 'silver',
+                material => 'silver',
                 plural => 'silver arrows',
             },
             'silver dagger' => {
@@ -869,7 +897,7 @@ sub list {
                 hands    => 1,
                 weight   => 12,
                 price    => 40,
-                material     => 'silver',
+                material => 'silver',
                 plural => 'silver daggers',
             },
             'silver saber' => {
@@ -879,7 +907,7 @@ sub list {
                 hands    => 1,
                 weight   => 40,
                 price    => 75,
-                material     => 'silver',
+                material => 'silver',
                 plural => 'silver sabers',
             },
             'silver spear' => {
@@ -889,7 +917,7 @@ sub list {
                 hands    => 1,
                 weight   => 36,
                 price    => 40,
-                material     => 'silver',
+                material => 'silver',
                 plural => 'silver spears',
             },
             'sling' => {
@@ -899,7 +927,7 @@ sub list {
                 hands    => 1,
                 weight   => 3,
                 price    => 20,
-                material     => 'leather',
+                material => 'leather',
                 plural => 'slings',
             },
             'spear' => {
@@ -909,7 +937,7 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 3,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'spears',
             },
             'spetum' => {
@@ -919,7 +947,7 @@ sub list {
                 hands    => 2,
                 weight   => 50,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'forked polearm',
                 plural => 'spetums',
             },
@@ -930,7 +958,7 @@ sub list {
                 hands    => 1,
                 weight   => 5,
                 price    => 4,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'stilettos',
             },
             'trident' => {
@@ -940,7 +968,7 @@ sub list {
                 hands    => 1,
                 weight   => 25,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'tridents',
             },
             'tsurugi' => {
@@ -950,7 +978,7 @@ sub list {
                 hands    => 2,
                 weight   => 60,
                 price    => 500,
-                material     => 'metal',
+                material => 'metal',
                 appearance => 'long samurai sword',
                 plural => 'tsurugis',
             },
@@ -961,7 +989,7 @@ sub list {
                 hands    => 2,
                 weight   => 150,
                 price    => 50,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'two-handed swords',
             },
             'unicorn horn' => {
@@ -971,7 +999,7 @@ sub list {
                 hands    => 2,
                 weight   => 20,
                 price    => 100,
-                material     => 'bone',
+                material => 'bone',
                 plural => 'unicorn horns',
             },
             'voulge' => {
@@ -981,7 +1009,7 @@ sub list {
                 hands    => 2,
                 weight   => 125,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 appearance => 'pole cleaver',
                 plural => 'voulges',
             },
@@ -992,7 +1020,7 @@ sub list {
                 hands    => 1,
                 weight   => 50,
                 price    => 5,
-                material     => 'iron',
+                material => 'iron',
                 plural => 'war hammers',
             },
             'worm tooth' => {
@@ -1002,7 +1030,7 @@ sub list {
                 hands    => 1,
                 weight   => 20,
                 price    => 2,
-                material     => 'none',
+                material => 'none',
                 plural => 'worm teeth',
             },
             'ya' => {
@@ -1012,7 +1040,7 @@ sub list {
                 hands    => 1,
                 weight   => 1,
                 price    => 4,
-                material     => 'metal',
+                material => 'metal',
                 appearance => 'bamboo arrow',
                 plural => 'ya',
             },
@@ -1023,21 +1051,12 @@ sub list {
                 hands    => 1,
                 weight   => 30,
                 price    => 60,
-                material     => 'wood',
+                material => 'wood',
                 appearance => 'long bow',
                 plural => 'yumis',
             },
     };
 
-    # tag each weapon with its name and appearance
-    for my $name (keys %$weapons) {
-        my $stats = $weapons->{$name};
-        $stats->{name}       = $name;
-        $stats->{type}       = 'weapon';
-        $stats->{appearance} = $name
-            unless $stats->{appearance} || $stats->{appearances};
-    }
-
     return $weapons;
 }
 
